@@ -23,7 +23,10 @@ class Distillery(object):
         """Inits, populates and saves a object instance.
         """
         instance = cls.init(**kwargs)
-        return cls.save(instance)
+        instance = cls.save(instance)
+        if hasattr(cls, '_after_create'):
+            cls._after_create(instance)
+        return instance
 
     @classmethod
     def init(cls, **kwargs):
@@ -159,22 +162,27 @@ class Set(object):
 
     def _get_member(self, fixture, key):
         def _get_foreign(member):
-            try:
-                if hasattr(member, '_set_class'):
-                    set_class = member._set_class
-                else:
-                    set_class = member.im_class
-                set_ = self._get_foreign_set_instance(set_class)
-                return getattr(set_, member.__name__)
-            except AttributeError:
+            if hasattr(member, '_set_class'):
+                set_class = member._set_class
+            elif hasattr(member, 'im_class'):
+                set_class = member.im_class
+            else:
                 raise Exception('%s does not appear to be a valid fixture' \
                     % member)
+            set_ = self._get_foreign_set_instance(set_class)
+            return getattr(set_, member.__name__)
 
         member = getattr(fixture, key)
         if isinstance(member, list) or isinstance(member, tuple):
             member = [_get_foreign(m) for m in member]
         elif callable(member):
-            member = _get_foreign(member)
+            if hasattr(member, 'im_class') and \
+                    not issubclass(member.im_class, Set):
+                member = member()
+                if hasattr(member, '_set_class'):
+                    member = _get_foreign(member)
+            else:
+                member = _get_foreign(member)
         return member
 
 
